aboutsummaryrefslogtreecommitdiff
path: root/gas
diff options
context:
space:
mode:
authorAlan Modra <amodra@gmail.com>2019-05-08 09:26:56 +0930
committerAlan Modra <amodra@gmail.com>2019-05-08 09:40:08 +0930
commit762172a4dc4c1a7c25b3ef18f32b6e378cac6487 (patch)
treef72811fa5576f29a9b9f1439d289df219ee06413 /gas
parent9632a526cae4cb10276e39d8c4bd1f649d13f8e8 (diff)
downloadgdb-762172a4dc4c1a7c25b3ef18f32b6e378cac6487.zip
gdb-762172a4dc4c1a7c25b3ef18f32b6e378cac6487.tar.gz
gdb-762172a4dc4c1a7c25b3ef18f32b6e378cac6487.tar.bz2
gas/elf dwarf2 tests
Make them work for tile, by using ".quad 0" as the simulated instruction and doubling size of aligns. The larger aligns tripped over riscv alignment handling, fixed by adding -mno-relax there. Also disable link-relax for avr, pru and xtensa, allowing these targets to pass these tests. With link-time relaxation enabled, these targets emit alignment relocations rather than aligning at assembly time. This means the assembler doesn't see a change in PC when it is expected over an alignment frag and thus view numbers are calculated incorrectly. * testsuite/gas/elf/dwarf2-1.s, * testsuite/gas/elf/dwarf2-2.s, * testsuite/gas/elf/dwarf2-5.s, * testsuite/gas/elf/dwarf2-7.s, * testsuite/gas/elf/dwarf2-8.s, * testsuite/gas/elf/dwarf2-9.s, * testsuite/gas/elf/dwarf2-10.s, * testsuite/gas/elf/dwarf2-11.s, * testsuite/gas/elf/dwarf2-12.s, * testsuite/gas/elf/dwarf2-13.s, * testsuite/gas/elf/dwarf2-14.s, * testsuite/gas/elf/dwarf2-15.s, * testsuite/gas/elf/dwarf2-16.s, * testsuite/gas/elf/dwarf2-17.s, * testsuite/gas/elf/dwarf2-18.s, * testsuite/gas/elf/dwarf2-19.s: Double size of align and simulated instructions. * testsuite/gas/elf/dwarf2-1.d, * testsuite/gas/elf/dwarf2-2.d, * testsuite/gas/elf/dwarf2-5.d, * testsuite/gas/elf/dwarf2-7.d, * testsuite/gas/elf/dwarf2-8.d, * testsuite/gas/elf/dwarf2-9.d, * testsuite/gas/elf/dwarf2-10.d, * testsuite/gas/elf/dwarf2-11.d, * testsuite/gas/elf/dwarf2-12.d, * testsuite/gas/elf/dwarf2-13.d, * testsuite/gas/elf/dwarf2-14.d, * testsuite/gas/elf/dwarf2-15.d, * testsuite/gas/elf/dwarf2-16.d, * testsuite/gas/elf/dwarf2-17.d, * testsuite/gas/elf/dwarf2-18.d, * testsuite/gas/elf/dwarf2-19.d: Use xfail rather than notarget. Remove avr, pru, tile, xtensa from xfails. Update expected output. * testsuite/gas/elf/elf.exp: Sort targets. (dump_opts): Pass {as -mno-relax} for riscv, {as -mno-link-relax} for avr and pru, and {as --no-link-relax} for xtensa to dwarf tests. * testsuite/gas/elf/section2.e-miwmmxt: Delete unused file.
Diffstat (limited to 'gas')
-rw-r--r--gas/ChangeLog41
-rw-r--r--gas/testsuite/gas/elf/dwarf2-1.d8
-rw-r--r--gas/testsuite/gas/elf/dwarf2-1.s4
-rw-r--r--gas/testsuite/gas/elf/dwarf2-10.d3
-rw-r--r--gas/testsuite/gas/elf/dwarf2-10.s10
-rw-r--r--gas/testsuite/gas/elf/dwarf2-11.d13
-rw-r--r--gas/testsuite/gas/elf/dwarf2-11.s6
-rw-r--r--gas/testsuite/gas/elf/dwarf2-12.d16
-rw-r--r--gas/testsuite/gas/elf/dwarf2-12.s4
-rw-r--r--gas/testsuite/gas/elf/dwarf2-13.d15
-rw-r--r--gas/testsuite/gas/elf/dwarf2-13.s8
-rw-r--r--gas/testsuite/gas/elf/dwarf2-14.d15
-rw-r--r--gas/testsuite/gas/elf/dwarf2-14.s6
-rw-r--r--gas/testsuite/gas/elf/dwarf2-15.d15
-rw-r--r--gas/testsuite/gas/elf/dwarf2-15.s6
-rw-r--r--gas/testsuite/gas/elf/dwarf2-16.d15
-rw-r--r--gas/testsuite/gas/elf/dwarf2-16.s8
-rw-r--r--gas/testsuite/gas/elf/dwarf2-17.d15
-rw-r--r--gas/testsuite/gas/elf/dwarf2-17.s8
-rw-r--r--gas/testsuite/gas/elf/dwarf2-18.d15
-rw-r--r--gas/testsuite/gas/elf/dwarf2-18.s6
-rw-r--r--gas/testsuite/gas/elf/dwarf2-19.d19
-rw-r--r--gas/testsuite/gas/elf/dwarf2-19.s4
-rw-r--r--gas/testsuite/gas/elf/dwarf2-2.d8
-rw-r--r--gas/testsuite/gas/elf/dwarf2-2.s4
-rw-r--r--gas/testsuite/gas/elf/dwarf2-5.d55
-rw-r--r--gas/testsuite/gas/elf/dwarf2-5.s14
-rw-r--r--gas/testsuite/gas/elf/dwarf2-7.d15
-rw-r--r--gas/testsuite/gas/elf/dwarf2-7.s4
-rw-r--r--gas/testsuite/gas/elf/dwarf2-8.d2
-rw-r--r--gas/testsuite/gas/elf/dwarf2-8.s2
-rw-r--r--gas/testsuite/gas/elf/dwarf2-9.d2
-rw-r--r--gas/testsuite/gas/elf/dwarf2-9.s2
-rw-r--r--gas/testsuite/gas/elf/elf.exp85
-rw-r--r--gas/testsuite/gas/elf/section2.e-miwmmxt10
35 files changed, 243 insertions, 220 deletions
diff --git a/gas/ChangeLog b/gas/ChangeLog
index 7234605..9de92c0 100644
--- a/gas/ChangeLog
+++ b/gas/ChangeLog
@@ -1,5 +1,46 @@
2019-05-08 Alan Modra <amodra@gmail.com>
+ * testsuite/gas/elf/dwarf2-1.s,
+ * testsuite/gas/elf/dwarf2-2.s,
+ * testsuite/gas/elf/dwarf2-5.s,
+ * testsuite/gas/elf/dwarf2-7.s,
+ * testsuite/gas/elf/dwarf2-8.s,
+ * testsuite/gas/elf/dwarf2-9.s,
+ * testsuite/gas/elf/dwarf2-10.s,
+ * testsuite/gas/elf/dwarf2-11.s,
+ * testsuite/gas/elf/dwarf2-12.s,
+ * testsuite/gas/elf/dwarf2-13.s,
+ * testsuite/gas/elf/dwarf2-14.s,
+ * testsuite/gas/elf/dwarf2-15.s,
+ * testsuite/gas/elf/dwarf2-16.s,
+ * testsuite/gas/elf/dwarf2-17.s,
+ * testsuite/gas/elf/dwarf2-18.s,
+ * testsuite/gas/elf/dwarf2-19.s: Double size of align and simulated
+ instructions.
+ * testsuite/gas/elf/dwarf2-1.d,
+ * testsuite/gas/elf/dwarf2-2.d,
+ * testsuite/gas/elf/dwarf2-5.d,
+ * testsuite/gas/elf/dwarf2-7.d,
+ * testsuite/gas/elf/dwarf2-8.d,
+ * testsuite/gas/elf/dwarf2-9.d,
+ * testsuite/gas/elf/dwarf2-10.d,
+ * testsuite/gas/elf/dwarf2-11.d,
+ * testsuite/gas/elf/dwarf2-12.d,
+ * testsuite/gas/elf/dwarf2-13.d,
+ * testsuite/gas/elf/dwarf2-14.d,
+ * testsuite/gas/elf/dwarf2-15.d,
+ * testsuite/gas/elf/dwarf2-16.d,
+ * testsuite/gas/elf/dwarf2-17.d,
+ * testsuite/gas/elf/dwarf2-18.d,
+ * testsuite/gas/elf/dwarf2-19.d: Use xfail rather than notarget.
+ Remove avr, pru, tile, xtensa from xfails. Update expected output.
+ * testsuite/gas/elf/elf.exp: Sort targets.
+ (dump_opts): Pass {as -mno-relax} for riscv, {as -mno-link-relax}
+ for avr and pru, and {as --no-link-relax} for xtensa to dwarf tests.
+ * testsuite/gas/elf/section2.e-miwmmxt: Delete unused file.
+
+2019-05-08 Alan Modra <amodra@gmail.com>
+
* config/tc-xtensa.c (opt_linkrelax): New variable.
(md_parse_option): Set it here.
(md_begin): Copy opt_linkrelax to linkrelax.
diff --git a/gas/testsuite/gas/elf/dwarf2-1.d b/gas/testsuite/gas/elf/dwarf2-1.d
index d456489..d1e0752 100644
--- a/gas/testsuite/gas/elf/dwarf2-1.d
+++ b/gas/testsuite/gas/elf/dwarf2-1.d
@@ -11,8 +11,8 @@ Contents of the .[z]?debug_info section:
Pointer Size: 4
<0><b>: Abbrev Number: 1 \(DW_TAG_compile_unit\)
<c> DW_AT_stmt_list : 0x0
- <10> DW_AT_high_pc : 0x.
- <14> DW_AT_low_pc : 0x.
+ <10> DW_AT_high_pc : 0x10
+ <14> DW_AT_low_pc : 0x8
<18> DW_AT_name : file1.txt
<22> DW_AT_producer : GNU C 3.3.3
<2e> DW_AT_language : 1 \(ANSI C\)
@@ -22,8 +22,8 @@ Contents of the .[z]?debug_info section:
<32> DW_AT_decl_line : 2
<33> DW_AT_name : func_cu1
<3c> DW_AT_type : <0x4a>
- <40> DW_AT_low_pc : 0x.
- <44> DW_AT_high_pc : 0x.
+ <40> DW_AT_low_pc : 0x8
+ <44> DW_AT_high_pc : 0x10
<48> DW_AT_frame_base : 1 byte block: 55 \(DW_OP_reg5 \([^()]*\)\)
<1><4a>: Abbrev Number: 3 \(DW_TAG_base_type\)
<4b> DW_AT_name : int
diff --git a/gas/testsuite/gas/elf/dwarf2-1.s b/gas/testsuite/gas/elf/dwarf2-1.s
index 505b998..dc0ce13 100644
--- a/gas/testsuite/gas/elf/dwarf2-1.s
+++ b/gas/testsuite/gas/elf/dwarf2-1.s
@@ -21,13 +21,13 @@
.text
.globl _start
_start:
- .int 0
+ .quad 0
.Lbegin_text1:
.globl func_cu1
.type func_cu1, %function
func_cu1:
.Lbegin_func_cu1:
- .int 0
+ .quad 0
.Lend_func_cu1:
.size func_cu1, .-func_cu1
.Lend_text1:
diff --git a/gas/testsuite/gas/elf/dwarf2-10.d b/gas/testsuite/gas/elf/dwarf2-10.d
index 9943d9e..e0e6816 100644
--- a/gas/testsuite/gas/elf/dwarf2-10.d
+++ b/gas/testsuite/gas/elf/dwarf2-10.d
@@ -2,5 +2,4 @@
#name: DWARF2 10
#error_output: dwarf2-10.l
# The mep target tries to relay code sections which breaks symbolic view computations.
-# The tile targets require 8-byte instructions, but the test only simulates 4-byte instructions.
-#notarget: mep-* tile*-*
+#xfail: mep-*
diff --git a/gas/testsuite/gas/elf/dwarf2-11.d b/gas/testsuite/gas/elf/dwarf2-11.d
index cdaa4f1..fbe1162 100644
--- a/gas/testsuite/gas/elf/dwarf2-11.d
+++ b/gas/testsuite/gas/elf/dwarf2-11.d
@@ -1,15 +1,14 @@
#as:
#readelf: -wL
#name: DWARF2 11
-# The am33 avr cr16 crx ft32 mn10 msp430 nds32 pru rl78 and xtensa targets do not evaluate the subtraction of symbols at assembly time.
+# The am33 cr16 crx ft32 mn10 msp430 nds32 and rl78 targets do not evaluate the subtraction of symbols at assembly time.
# The riscv targets do not support the subtraction of symbols.
-# The tile targets require 8-byte instructions, but the test only simulates 4-byte instructions.
-#notarget: am3*-* avr-* cr16-* crx-* ft32*-* mn10*-* msp430-* nds32*-* pru-* riscv*-* rl78-* tile*-* xtensa-*
+#xfail: am3*-* cr16-* crx-* ft32*-* mn10*-* msp430-* nds32*-* riscv*-* rl78-*
Contents of the \.debug_line section:
CU: dwarf2-11\.c:
-File name *Line number *Starting address *View +Stmt
-dwarf2-11\.c *1 *0x4 +x
-dwarf2-11\.c *2 *0x8 +x
-dwarf2-11\.c *2 *0x8 *1 +x
+File name +Line number +Starting address +View +Stmt
+dwarf2-11\.c +1 +0x8 +x
+dwarf2-11\.c +2 +0x10 +x
+dwarf2-11\.c +2 +0x10 +1 +x
diff --git a/gas/testsuite/gas/elf/dwarf2-11.s b/gas/testsuite/gas/elf/dwarf2-11.s
index 327ac67..7d0d49b 100644
--- a/gas/testsuite/gas/elf/dwarf2-11.s
+++ b/gas/testsuite/gas/elf/dwarf2-11.s
@@ -17,12 +17,12 @@
.file "dwarf2-11.c"
.text
- .balign 8
+ .balign 16
.globl _start
_start:
.file 1 "dwarf2-11.c"
- .dc.l 0
+ .quad 0
.loc 1 1 view 0
- .balign 8
+ .balign 16
.loc 1 2 view 0
.size _start, .-_start
diff --git a/gas/testsuite/gas/elf/dwarf2-12.d b/gas/testsuite/gas/elf/dwarf2-12.d
index 58cda41..eaa22e4 100644
--- a/gas/testsuite/gas/elf/dwarf2-12.d
+++ b/gas/testsuite/gas/elf/dwarf2-12.d
@@ -1,11 +1,9 @@
#as:
#readelf: -x.rodata -wL
#name: DWARF2 12
-# The am33 avr cr16 crx ft32 mn10 msp430 nds32 pru rl78 and xtensa targets do not evaluate the subtraction of symbols at assembly time.
+# The am33 cr16 crx ft32 mn10 msp430 nds32 and rl78 targets do not evaluate the subtraction of symbols at assembly time.
# The riscv targets do not support the subtraction of symbols.
-# The tile targets require 8-byte instructions, but the test only simulates 4-byte instructions.
-#notarget: am3*-* avr-* cr16-* crx-* ft32-* mn10*-* msp430-* nds32*-* pru-* riscv*-* rl78-* tile*-* xtensa-*
-
+#xfail: am3*-* cr16-* crx-* ft32-* mn10*-* msp430-* nds32*-* riscv*-* rl78-*
Hex dump of section '\.rodata':
0x00000000 01 *.*
@@ -13,8 +11,8 @@ Hex dump of section '\.rodata':
Contents of the \.debug_line section:
CU: dwarf2-12\.c:
-File name *Line number *Starting address *View +Stmt
-dwarf2-12\.c *1 *0 +x
-dwarf2-12\.c *2 *0 +x
-dwarf2-12\.c *3 *0 *1 +x
-dwarf2-12\.c *3 *0x4 +x
+File name +Line number +Starting address +View +Stmt
+dwarf2-12\.c +1 +0 +x
+dwarf2-12\.c +2 +0 +x
+dwarf2-12\.c +3 +0 +1 +x
+dwarf2-12\.c +3 +0x8 +x
diff --git a/gas/testsuite/gas/elf/dwarf2-12.s b/gas/testsuite/gas/elf/dwarf2-12.s
index 4ce139b..c682f70 100644
--- a/gas/testsuite/gas/elf/dwarf2-12.s
+++ b/gas/testsuite/gas/elf/dwarf2-12.s
@@ -17,14 +17,14 @@
.file "dwarf2-12.c"
.text
- .balign 4
+ .balign 8
.globl _start
_start:
.file 1 "dwarf2-12.c"
.loc 1 1 view 0
.loc 1 2 view -0
.loc 1 3 view .L1
- .dc.l 0
+ .quad 0
.size _start, .-_start
.section .rodata
diff --git a/gas/testsuite/gas/elf/dwarf2-13.d b/gas/testsuite/gas/elf/dwarf2-13.d
index bcda370..fd1f058 100644
--- a/gas/testsuite/gas/elf/dwarf2-13.d
+++ b/gas/testsuite/gas/elf/dwarf2-13.d
@@ -1,10 +1,9 @@
#as:
#readelf: -x.rodata -wL
#name: DWARF2 13
-# The am33 avr cr16 crx ft32 mn10 msp430 nds32 pru rl78 and xtensa targets do not evaluate the subtraction of symbols at assembly time.
+# The am33 cr16 crx ft32 mn10 msp430 nds32 and rl78 targets do not evaluate the subtraction of symbols at assembly time.
# The riscv targets do not support the subtraction of symbols.
-# The tile targets require 8-byte instructions, but the test only simulates 4-byte instructions.
-#notarget: am3*-* avr-* cr16-* crx-* ft32*-* mn10*-* msp430-* nds32*-* pru-* riscv*-* rl78-* tile*-* xtensa-*
+#xfail: am3*-* cr16-* crx-* ft32*-* mn10*-* msp430-* nds32*-* riscv*-* rl78-*
Hex dump of section '\.rodata':
0x00000000 01 *.*
@@ -12,8 +11,8 @@ Hex dump of section '\.rodata':
Contents of the \.debug_line section:
CU: dwarf2-13\.c:
-File name *Line number *Starting address *View +Stmt
-dwarf2-13\.c *1 *0x4 +x
-dwarf2-13\.c *2 *0x8 +x
-dwarf2-13\.c *3 *0x8 *1 +x
-dwarf2-13\.c *3 *0xc +x
+File name +Line number +Starting address +View +Stmt
+dwarf2-13\.c +1 +0x8 +x
+dwarf2-13\.c +2 +0x10 +x
+dwarf2-13\.c +3 +0x10 +1 +x
+dwarf2-13\.c +3 +0x18 +x
diff --git a/gas/testsuite/gas/elf/dwarf2-13.s b/gas/testsuite/gas/elf/dwarf2-13.s
index c18f752..f8fc1b3 100644
--- a/gas/testsuite/gas/elf/dwarf2-13.s
+++ b/gas/testsuite/gas/elf/dwarf2-13.s
@@ -17,16 +17,16 @@
.file "dwarf2-13.c"
.text
- .balign 8
+ .balign 16
.globl _start
_start:
.file 1 "dwarf2-13.c"
- .dc.l 0
+ .quad 0
.loc 1 1 view 0
- .balign 8
+ .balign 16
.loc 1 2 view -0
.loc 1 3 view .L1
- .dc.l 0
+ .quad 0
.size _start, .-_start
.section .rodata
diff --git a/gas/testsuite/gas/elf/dwarf2-14.d b/gas/testsuite/gas/elf/dwarf2-14.d
index d0ee7c3..c94e4a8 100644
--- a/gas/testsuite/gas/elf/dwarf2-14.d
+++ b/gas/testsuite/gas/elf/dwarf2-14.d
@@ -1,10 +1,9 @@
#as:
#readelf: -x.rodata -wL
#name: DWARF2 14
-# The am33 avr cr16 crx mn10 ft32 msp430 nds32 pru rl78 and xtensa targets do not evaluate the subtraction of symbols at assembly time
+# The am33 cr16 crx mn10 ft32 msp430 nds32 and rl78 targets do not evaluate the subtraction of symbols at assembly time
# The riscv targets do not support the subtraction of symbols.
-# The tile targets require 8-byte instructions, but the test only simulates 4-byte instructions.
-#notarget: am3*-* avr-* cr16-* crx-* ft32*-* mn10*-* msp430-* nds32*-* pru-* riscv*-* rl78-* tile*-* xtensa-*
+#xfail: am3*-* cr16-* crx-* ft32*-* mn10*-* msp430-* nds32*-* riscv*-* rl78-*
Hex dump of section '\.rodata':
0x00000000 01 *.*
@@ -12,8 +11,8 @@ Hex dump of section '\.rodata':
Contents of the \.debug_line section:
CU: dwarf2-14\.c:
-File name *Line number *Starting address *View +Stmt
-dwarf2-14\.c *1 *0 +x
-dwarf2-14\.c *2 *0 +x
-dwarf2-14\.c *3 *0 *1 +x
-dwarf2-14\.c *3 *0x4 +x
+File name +Line number +Starting address +View +Stmt
+dwarf2-14\.c +1 +0 +x
+dwarf2-14\.c +2 +0 +x
+dwarf2-14\.c +3 +0 +1 +x
+dwarf2-14\.c +3 +0x8 +x
diff --git a/gas/testsuite/gas/elf/dwarf2-14.s b/gas/testsuite/gas/elf/dwarf2-14.s
index 55bb0a8..31d4a1b 100644
--- a/gas/testsuite/gas/elf/dwarf2-14.s
+++ b/gas/testsuite/gas/elf/dwarf2-14.s
@@ -17,15 +17,15 @@
.file "dwarf2-14.c"
.text
- .balign 4
+ .balign 8
.globl _start
_start:
.file 1 "dwarf2-14.c"
.loc 1 1 view 0
- .balign 4
+ .balign 8
.loc 1 2 view -0
.loc 1 3 view .L1
- .dc.l 0
+ .quad 0
.size _start, .-_start
.section .rodata
diff --git a/gas/testsuite/gas/elf/dwarf2-15.d b/gas/testsuite/gas/elf/dwarf2-15.d
index 77ba210..f4af8a8 100644
--- a/gas/testsuite/gas/elf/dwarf2-15.d
+++ b/gas/testsuite/gas/elf/dwarf2-15.d
@@ -1,10 +1,9 @@
#as:
#readelf: -x.rodata -wL
#name: DWARF2 15
-# The am33 avr cr16 crx ft32 mn10 msp430 nds32 pru rl78 and xtensa targets do not evaluate the subtraction of symbols at assembly time.
+# The am33 cr16 crx ft32 mn10 msp430 nds32 and rl78 targets do not evaluate the subtraction of symbols at assembly time.
# The riscv targets do not support the subtraction of symbols.
-# The tile targets require 8-byte instructions, but the test only simulates 4-byte instructions.
-#notarget: am3*-* avr-* cr16-* crx-* ft32*-* mn10*-* msp430-* nds32*-* pru-* riscv*-* rl78-* tile*-* xtensa-*
+#xfail: am3*-* cr16-* crx-* ft32*-* mn10*-* msp430-* nds32*-* riscv*-* rl78-*
Hex dump of section '\.rodata':
0x00000000 01 *.*
@@ -12,8 +11,8 @@ Hex dump of section '\.rodata':
Contents of the \.debug_line section:
CU: dwarf2-15\.c:
-File name *Line number *Starting address *View +Stmt
-dwarf2-15\.c *1 *0 +x
-dwarf2-15\.c *2 *0x4 +x
-dwarf2-15\.c *3 *0x4 *1 +x
-dwarf2-15\.c *3 *0x8 +x
+File name +Line number +Starting address +View +Stmt
+dwarf2-15\.c +1 +0 +x
+dwarf2-15\.c +2 +0x8 +x
+dwarf2-15\.c +3 +0x8 +1 +x
+dwarf2-15\.c +3 +0x10 +x
diff --git a/gas/testsuite/gas/elf/dwarf2-15.s b/gas/testsuite/gas/elf/dwarf2-15.s
index fb971f0..2e8cc83 100644
--- a/gas/testsuite/gas/elf/dwarf2-15.s
+++ b/gas/testsuite/gas/elf/dwarf2-15.s
@@ -17,15 +17,15 @@
.file "dwarf2-15.c"
.text
- .balign 8
+ .balign 16
.globl _start
_start:
.file 1 "dwarf2-15.c"
.loc 1 1 view 0
- .dc.l 0
+ .quad 0
.loc 1 2 view -0
.loc 1 3 view .L1
- .dc.l 0
+ .quad 0
.size _start, .-_start
.section .rodata
diff --git a/gas/testsuite/gas/elf/dwarf2-16.d b/gas/testsuite/gas/elf/dwarf2-16.d
index b8a45c8..f7cdddb 100644
--- a/gas/testsuite/gas/elf/dwarf2-16.d
+++ b/gas/testsuite/gas/elf/dwarf2-16.d
@@ -1,11 +1,10 @@
#as:
#readelf: -x.rodata -wL
#name: DWARF2 16
-# The am33 avr cr16 crx ft32 mn10 msp430 nds32 pru rl78 and xtensa targets do not evaluate the subtraction of symbols at assembly time.
+# The am33 cr16 crx ft32 mn10 msp430 nds32 and rl78 targets do not evaluate the subtraction of symbols at assembly time.
# The mep target tries to relay code sections which breaks symbolic view computations.
# The riscv targets do not support the subtraction of symbols.
-# The tile targets require 8-byte instructions, but the test only simulates 4-byte instructions.
-#notarget: am3*-* avr-* cr16-* crx-* ft32*-* mep-* mn10*-* msp430-* nds32*-* pru-* riscv*-* rl78-* tile*-* xtensa-*
+#xfail: am3*-* cr16-* crx-* ft32*-* mep-* mn10*-* msp430-* nds32*-* riscv*-* rl78-*
Hex dump of section '\.rodata':
0x00000000 01 *.*
@@ -13,8 +12,8 @@ Hex dump of section '\.rodata':
Contents of the \.debug_line section:
CU: dwarf2-16\.c:
-File name *Line number *Starting address *View +Stmt
-dwarf2-16\.c *1 *0 +x
-dwarf2-16\.c *2 *0x4 +x
-dwarf2-16\.c *3 *0x4 *1 +x
-dwarf2-16\.c *3 *0x8 +x
+File name +Line number +Starting address +View +Stmt
+dwarf2-16\.c +1 +0 +x
+dwarf2-16\.c +2 +0x8 +x
+dwarf2-16\.c +3 +0x8 +1 +x
+dwarf2-16\.c +3 +0x10 +x
diff --git a/gas/testsuite/gas/elf/dwarf2-16.s b/gas/testsuite/gas/elf/dwarf2-16.s
index 0e3357c..5605f85 100644
--- a/gas/testsuite/gas/elf/dwarf2-16.s
+++ b/gas/testsuite/gas/elf/dwarf2-16.s
@@ -17,16 +17,16 @@
.file "dwarf2-16.c"
.text
- .balign 8
+ .balign 16
.globl _start
_start:
.file 1 "dwarf2-16.c"
.loc 1 1 view 0
- .dc.l 0
+ .quad 0
.loc 1 2 view 0
- .balign 4
+ .balign 8
.loc 1 3 view .L1
- .dc.l 0
+ .quad 0
.size _start, .-_start
.section .rodata
diff --git a/gas/testsuite/gas/elf/dwarf2-17.d b/gas/testsuite/gas/elf/dwarf2-17.d
index fbd474e..2eb1e66 100644
--- a/gas/testsuite/gas/elf/dwarf2-17.d
+++ b/gas/testsuite/gas/elf/dwarf2-17.d
@@ -1,11 +1,10 @@
#as:
#readelf: -x.rodata -wL
#name: DWARF2 17
-# The am33 avr cr16 crx ft32 mn10 msp430 nds32 pru rl78 and xtensa targets do not evaluate the subtraction of symbols at assembly time.
+# The am33 cr16 crx ft32 mn10 msp430 nds32 and rl78 targets do not evaluate the subtraction of symbols at assembly time.
# The mep target tries to relay code sections which breaks symbolic view computations.
# The riscv targets do not support the subtraction of symbols.
-# The tile targets require 8-byte instructions, but the test only simulates 4-byte instructions.
-#notarget: am3*-* avr-* cr16-* crx-* ft32*-* mep-* mn10*-* msp430-* nds32*-* pru-* riscv*-* rl78-* tile*-* xtensa-*
+#xfail: am3*-* cr16-* crx-* ft32*-* mep-* mn10*-* msp430-* nds32*-* riscv*-* rl78-*
Hex dump of section '\.rodata':
0x00000000 00 *.*
@@ -13,8 +12,8 @@ Hex dump of section '\.rodata':
Contents of the \.debug_line section:
CU: dwarf2-17\.c:
-File name *Line number *Starting address *View +Stmt
-dwarf2-17\.c *1 *0 +x
-dwarf2-17\.c *2 *0x4 +x
-dwarf2-17\.c *3 *0x8 +x
-dwarf2-17\.c *3 *0xc +x
+File name +Line number +Starting address +View +Stmt
+dwarf2-17\.c +1 +0 +x
+dwarf2-17\.c +2 +0x8 +x
+dwarf2-17\.c +3 +0x10 +x
+dwarf2-17\.c +3 +0x18 +x
diff --git a/gas/testsuite/gas/elf/dwarf2-17.s b/gas/testsuite/gas/elf/dwarf2-17.s
index 1954792..1188136 100644
--- a/gas/testsuite/gas/elf/dwarf2-17.s
+++ b/gas/testsuite/gas/elf/dwarf2-17.s
@@ -17,16 +17,16 @@
.file "dwarf2-17.c"
.text
- .balign 8
+ .balign 16
.globl _start
_start:
.file 1 "dwarf2-17.c"
.loc 1 1 view 0
- .dc.l 0
+ .quad 0
.loc 1 2 view 0
- .balign 8
+ .balign 16
.loc 1 3 view .L1
- .dc.l 0
+ .quad 0
.size _start, .-_start
.section .rodata
diff --git a/gas/testsuite/gas/elf/dwarf2-18.d b/gas/testsuite/gas/elf/dwarf2-18.d
index 8d47aae..81a075c 100644
--- a/gas/testsuite/gas/elf/dwarf2-18.d
+++ b/gas/testsuite/gas/elf/dwarf2-18.d
@@ -1,11 +1,10 @@
#as:
#readelf: -x.rodata -wL
#name: DWARF2 18
-# The am33 avr cr16 crx ft32 mn10 msp430 nds32 pru rl78 and xtensa targets do not evaluate the subtraction of symbols at assembly time.
+# The am33 cr16 crx ft32 mn10 msp430 nds32 and rl78 targets do not evaluate the subtraction of symbols at assembly time.
# The mep targets turns some view computations into complex relocations.
# The riscv targets do not support the subtraction of symbols.
-# The tile targets require 8-byte instructions, but the test only simulates 4-byte instructions.
-#notarget: am3*-* avr-* cr16-* crx-* ft32*-* mep-* mn10*-* msp430-* nds32*-* pru-* riscv*-* rl78-* tile*-* xtensa-*
+#xfail: am3*-* cr16-* crx-* ft32*-* mep-* mn10*-* msp430-* nds32*-* riscv*-* rl78-*
Hex dump of section '\.rodata':
0x00000000 0100 *.*
@@ -13,8 +12,8 @@ Hex dump of section '\.rodata':
Contents of the \.debug_line section:
CU: dwarf2-18\.c:
-File name *Line number *Starting address *View +Stmt
-dwarf2-18\.c *1 *0 +x
-dwarf2-18\.c *2 *0 *1 +x
-dwarf2-18\.c *3 *0x4 +x
-dwarf2-18\.c *3 *0x8 +x
+File name +Line number +Starting address +View +Stmt
+dwarf2-18\.c +1 +0 +x
+dwarf2-18\.c +2 +0 +1 +x
+dwarf2-18\.c +3 +0x8 +x
+dwarf2-18\.c +3 +0x10 +x
diff --git a/gas/testsuite/gas/elf/dwarf2-18.s b/gas/testsuite/gas/elf/dwarf2-18.s
index 7024f4c..5baf089 100644
--- a/gas/testsuite/gas/elf/dwarf2-18.s
+++ b/gas/testsuite/gas/elf/dwarf2-18.s
@@ -17,15 +17,15 @@
.file "dwarf2-18.c"
.text
- .balign 8
+ .balign 16
.globl _start
_start:
.file 1 "dwarf2-18.c"
.loc 1 1
.loc 1 2 view .L1
- .dc.l 0
+ .quad 0
.loc 1 3 view .L2
- .dc.l 0
+ .quad 0
.size _start, .-_start
.section .rodata
diff --git a/gas/testsuite/gas/elf/dwarf2-19.d b/gas/testsuite/gas/elf/dwarf2-19.d
index 2c38e4e..dd70dd3 100644
--- a/gas/testsuite/gas/elf/dwarf2-19.d
+++ b/gas/testsuite/gas/elf/dwarf2-19.d
@@ -1,11 +1,10 @@
#as:
#readelf: -x.rodata -wL
#name: DWARF2 19
-# The am33 avr cr16 crx ft32 mn10 msp430 nds32 pru rl78 and xtensa targets do not evaluate the subtraction of symbols at assembly time.
+# The am33 cr16 crx ft32 mn10 msp430 nds32 and rl78 targets do not evaluate the subtraction of symbols at assembly time.
# The mep targets turns some view computations into complex relocations.
# The riscv targets do not support the subtraction of symbols.
-# The tile targets require 8-byte instructions, but the test only simulates 4-byte instructions.
-#notarget: am3*-* avr-* cr16-* crx-* ft32*-* mep-* mn10*-* msp430-* nds32*-* pru-* riscv*-* rl78-* tile*-* xtensa-*
+#xfail: am3*-* cr16-* crx-* ft32*-* mep-* mn10*-* msp430-* nds32*-* riscv*-* rl78-*
Hex dump of section '\.rodata':
0x00000000 01000102 *.*
@@ -13,10 +12,10 @@ Hex dump of section '\.rodata':
Contents of the \.debug_line section:
CU: dwarf2-19\.c:
-File name *Line number *Starting address *View +Stmt
-dwarf2-19\.c *1 *0 +x
-dwarf2-19\.c *2 *0 *1 +x
-dwarf2-19\.c *4 *0x4 +x
-dwarf2-19\.c *5 *0x4 *1 +x
-dwarf2-19\.c *3 *0x4 *2 +x
-dwarf2-19\.c *3 *0x4 *3 +x
+File name +Line number +Starting address +View +Stmt
+dwarf2-19\.c +1 +0 +x
+dwarf2-19\.c +2 +0 +1 +x
+dwarf2-19\.c +4 +0x8 +x
+dwarf2-19\.c +5 +0x8 +1 +x
+dwarf2-19\.c +3 +0x8 +2 +x
+dwarf2-19\.c +3 +0x8 +3 +x
diff --git a/gas/testsuite/gas/elf/dwarf2-19.s b/gas/testsuite/gas/elf/dwarf2-19.s
index dd87be8..20821603 100644
--- a/gas/testsuite/gas/elf/dwarf2-19.s
+++ b/gas/testsuite/gas/elf/dwarf2-19.s
@@ -17,7 +17,7 @@
.file "dwarf2-19.c"
.text 0
- .balign 4
+ .balign 8
.globl _start
_start:
.file 1 "dwarf2-19.c"
@@ -36,6 +36,6 @@ _start:
.loc 1 3 view .L2 /* same address as .L4 below -> view 2 */
.text 1
- .dc.l 0
+ .quad 0
.loc 1 4 view .L3 /* bumped address from .L1's, view 0 */
.loc 1 5 view .L4 /* same address, view 1 */
diff --git a/gas/testsuite/gas/elf/dwarf2-2.d b/gas/testsuite/gas/elf/dwarf2-2.d
index a93f03e..eb33a01 100644
--- a/gas/testsuite/gas/elf/dwarf2-2.d
+++ b/gas/testsuite/gas/elf/dwarf2-2.d
@@ -11,8 +11,8 @@ Contents of the .[z]?debug_info section:
Pointer Size: 4
<0><b>: Abbrev Number: 1 \(DW_TAG_compile_unit\)
<c> DW_AT_stmt_list : 0x0
- <10> DW_AT_high_pc : 0x.
- <14> DW_AT_low_pc : 0x.
+ <10> DW_AT_high_pc : 0x10
+ <14> DW_AT_low_pc : 0x8
<18> DW_AT_name : file1.txt
<22> DW_AT_producer : GNU C 3.3.3
<2e> DW_AT_language : 1 \(ANSI C\)
@@ -22,8 +22,8 @@ Contents of the .[z]?debug_info section:
<32> DW_AT_decl_line : 2
<33> DW_AT_name : func_cu1
<3c> DW_AT_type : <0x4a>
- <40> DW_AT_low_pc : 0x.
- <44> DW_AT_high_pc : 0x.
+ <40> DW_AT_low_pc : 0x8
+ <44> DW_AT_high_pc : 0x10
<48> DW_AT_frame_base : 1 byte block: 55 \(DW_OP_reg5 \([^()]*\)\)
<1><4a>: Abbrev Number: 3 \(DW_TAG_base_type\)
<4b> DW_AT_name : int
diff --git a/gas/testsuite/gas/elf/dwarf2-2.s b/gas/testsuite/gas/elf/dwarf2-2.s
index d97623e..a8594e5 100644
--- a/gas/testsuite/gas/elf/dwarf2-2.s
+++ b/gas/testsuite/gas/elf/dwarf2-2.s
@@ -21,13 +21,13 @@
.section .gnu.linkonce.t.foo,"axG",%progbits,foo,comdat
.globl _start
_start:
- .int 0
+ .quad 0
.Lbegin_text1:
.globl func_cu1
.type func_cu1, %function
func_cu1:
.Lbegin_func_cu1:
- .int 0
+ .quad 0
.Lend_func_cu1:
.size func_cu1, .-func_cu1
.Lend_text1:
diff --git a/gas/testsuite/gas/elf/dwarf2-5.d b/gas/testsuite/gas/elf/dwarf2-5.d
index e04f546..59f458d 100644
--- a/gas/testsuite/gas/elf/dwarf2-5.d
+++ b/gas/testsuite/gas/elf/dwarf2-5.d
@@ -1,11 +1,10 @@
#as:
#readelf: -x.rodata -wlL
#name: DWARF2 5
-# The am33 avr cr16 crx ft32 mn10 msp430 nds32 pru rl78 rx and xtensa targets do not evaluate the subtraction of symbols at assembly time.
+# The am33 cr16 crx ft32 mn10 msp430 nds32 rl78 and rx targets do not evaluate the subtraction of symbols at assembly time.
# The mep target tries to relay code sections which breaks symbolic view computations.
# The riscv targets do not support the subtraction of symbols.
-# The tile targets require 8-byte instructions, but the test only simulates 4-byte instructions.
-#notarget: am3*-* avr-* cr16-* crx-* ft32*-* mep-* mn10*-* msp430-* nds32*-* pru-* riscv*-* rl78-* rx-* tile*-* xtensa-*
+#xfail: am3*-* cr16-* crx-* ft32*-* mep-* mn10*-* msp430-* nds32*-* riscv*-* rl78-* rx-*
Hex dump of section '\.rodata':
0x00000000 01010201 010203 *.*
@@ -46,34 +45,34 @@ Raw dump of debug contents of section \.debug_line:
\[0x.*\] Extended opcode 2: set Address to 0x0
\[0x.*\] Copy
\[0x.*\] Special opcode [0-9]*: advance Address by 0 to 0x0 and Line by 1 to 2 \(view 1\)
- \[0x.*\] Special opcode [0-9]*: advance Address by 4 to 0x4 and Line by 1 to 3
- \[0x.*\] Special opcode [0-9]*: advance Address by 0 to 0x4 and Line by 1 to 4 \(view 1\)
- \[0x.*\] Special opcode [0-9]*: advance Address by 0 to 0x4 and Line by 1 to 5 \(view 2\)
- \[0x.*\] Special opcode [0-9]*: advance Address by 4 to 0x8 and Line by 1 to 6
- \[0x.*\] Special opcode [0-9]*: advance Address by 4 to 0xc and Line by 1 to 7
- \[0x.*\] Special opcode [0-9]*: advance Address by 0 to 0xc and Line by 1 to 8 \(view 1\)
- \[0x.*\] Special opcode [0-9]*: advance Address by 4 to 0x10 and Line by 1 to 9
- \[0x.*\] Special opcode [0-9]*: advance Address by 0 to 0x10 and Line by 1 to 10 \(view 1\)
- \[0x.*\] Special opcode [0-9]*: advance Address by 0 to 0x10 and Line by 1 to 11 \(view 2\)
- \[0x.*\] Special opcode [0-9]*: advance Address by 0 to 0x10 and Line by 1 to 12 \(view 3\)
- \[0x.*\] Advance PC by 4 to 0x14
+ \[0x.*\] Special opcode [0-9]*: advance Address by 8 to 0x8 and Line by 1 to 3
+ \[0x.*\] Special opcode [0-9]*: advance Address by 0 to 0x8 and Line by 1 to 4 \(view 1\)
+ \[0x.*\] Special opcode [0-9]*: advance Address by 0 to 0x8 and Line by 1 to 5 \(view 2\)
+ \[0x.*\] Special opcode [0-9]*: advance Address by 8 to 0x10 and Line by 1 to 6
+ \[0x.*\] Special opcode [0-9]*: advance Address by 8 to 0x18 and Line by 1 to 7
+ \[0x.*\] Special opcode [0-9]*: advance Address by 0 to 0x18 and Line by 1 to 8 \(view 1\)
+ \[0x.*\] Special opcode [0-9]*: advance Address by 8 to 0x20 and Line by 1 to 9
+ \[0x.*\] Special opcode [0-9]*: advance Address by 0 to 0x20 and Line by 1 to 10 \(view 1\)
+ \[0x.*\] Special opcode [0-9]*: advance Address by 0 to 0x20 and Line by 1 to 11 \(view 2\)
+ \[0x.*\] Special opcode [0-9]*: advance Address by 0 to 0x20 and Line by 1 to 12 \(view 3\)
+ \[0x.*\] Advance PC by 8 to 0x28
\[0x.*\] Extended opcode 1: End of Sequence
Contents of the \.debug_line section:
CU: dwarf2-5\.c:
-File name *Line number *Starting address *View +Stmt
-dwarf2-5\.c *1 *0 +x
-dwarf2-5\.c *2 *0 *1 +x
-dwarf2-5\.c *3 *0x4 +x
-dwarf2-5\.c *4 *0x4 *1 +x
-dwarf2-5\.c *5 *0x4 *2 +x
-dwarf2-5\.c *6 *0x8 +x
-dwarf2-5\.c *7 *0xc +x
-dwarf2-5\.c *8 *0xc *1 +x
-dwarf2-5\.c *9 *0x10 +x
-dwarf2-5\.c *10 *0x10 *1 +x
-dwarf2-5\.c *11 *0x10 *2 +x
-dwarf2-5\.c *12 *0x10 *3 +x
-dwarf2-5\.c *12 *0x14 +x
+File name +Line number +Starting address +View +Stmt
+dwarf2-5\.c +1 +0 +x
+dwarf2-5\.c +2 +0 +1 +x
+dwarf2-5\.c +3 +0x8 +x
+dwarf2-5\.c +4 +0x8 +1 +x
+dwarf2-5\.c +5 +0x8 +2 +x
+dwarf2-5\.c +6 +0x10 +x
+dwarf2-5\.c +7 +0x18 +x
+dwarf2-5\.c +8 +0x18 +1 +x
+dwarf2-5\.c +9 +0x20 +x
+dwarf2-5\.c +10 +0x20 +1 +x
+dwarf2-5\.c +11 +0x20 +2 +x
+dwarf2-5\.c +12 +0x20 +3 +x
+dwarf2-5\.c +12 +0x28 +x
diff --git a/gas/testsuite/gas/elf/dwarf2-5.s b/gas/testsuite/gas/elf/dwarf2-5.s
index a1d87e9..7b13e27 100644
--- a/gas/testsuite/gas/elf/dwarf2-5.s
+++ b/gas/testsuite/gas/elf/dwarf2-5.s
@@ -17,35 +17,35 @@
.file "dwarf2-5.c"
.text
- .balign 4
+ .balign 8
.globl _start
_start:
.file 1 "dwarf2-5.c"
.loc 1 1 view 0
.loc 1 2 view .L2
- .dc.l 0
+ .quad 0
.loc 1 3 view 0
- .balign 4
+ .balign 8
.loc 1 4 view .L4
.loc 1 5 view .L5
.org .+1
- .balign 4
+ .balign 8
.loc 1 6 view 0
- .dc.l 0
+ .quad 0
.text
.globl func
.type func, %function
func:
.loc 1 7 view 0
.loc 1 8 view .L8
- .dc.l 0
+ .quad 0
.loc 1 9 view 0
.loc 1 10 view .L10
.pushsection .text
.loc 1 11 view .L11
.popsection
.loc 1 12 view .L12
- .dc.l 0
+ .quad 0
.size func, .-func
.section .rodata
diff --git a/gas/testsuite/gas/elf/dwarf2-7.d b/gas/testsuite/gas/elf/dwarf2-7.d
index 2f457aa..59a22d0 100644
--- a/gas/testsuite/gas/elf/dwarf2-7.d
+++ b/gas/testsuite/gas/elf/dwarf2-7.d
@@ -1,10 +1,9 @@
#as:
#readelf: -x.rodata -wL
#name: DWARF2 7
-# The am33 avr cr16 crx ft32 mn10 msp430 nds32 pru rl78 and xtensa targets do not evaluate the subtraction of symbols at assembly time.
+# The am33 cr16 crx ft32 mn10 msp430 nds32 and rl78 targets do not evaluate the subtraction of symbols at assembly time.
# The riscv targets do not support the subtraction of symbols.
-# The tile targets require 8-byte instructions, but the test only simulates 4-byte instructions.
-#notarget: am3*-* avr-* cr16-* crx-* ft32*-* mn10*-* msp430-* nds32*-* pru-* riscv*-* rl78-* tile*-* xtensa-*
+#xfail: am3*-* cr16-* crx-* ft32*-* mn10*-* msp430-* nds32*-* riscv*-* rl78-*
Hex dump of section '\.rodata':
0x00000000 01 *.*
@@ -12,8 +11,8 @@ Hex dump of section '\.rodata':
Contents of the \.debug_line section:
CU: dwarf2-7\.c:
-File name *Line number *Starting address *View +Stmt
-dwarf2-7\.c *1 *0 +x
-dwarf2-7\.c *2 *0 +x
-dwarf2-7\.c *3 *0 *1 +x
-dwarf2-7\.c *3 *0x. +x
+File name +Line number +Starting address +View +Stmt
+dwarf2-7\.c +1 +0 +x
+dwarf2-7\.c +2 +0 +x
+dwarf2-7\.c +3 +0 +1 +x
+dwarf2-7\.c +3 +0x8 +x
diff --git a/gas/testsuite/gas/elf/dwarf2-7.s b/gas/testsuite/gas/elf/dwarf2-7.s
index 6b21f25..1f0fe8a 100644
--- a/gas/testsuite/gas/elf/dwarf2-7.s
+++ b/gas/testsuite/gas/elf/dwarf2-7.s
@@ -17,7 +17,7 @@
.file "dwarf2-7.c"
.text
- .balign 4
+ .balign 8
.globl _start
_start:
.file 1 "dwarf2-7.c"
@@ -32,5 +32,5 @@ _start:
func:
.loc 1 2 view -0
.loc 1 3 view .L1
- .dc.l 0
+ .quad 0
.size func, .-func
diff --git a/gas/testsuite/gas/elf/dwarf2-8.d b/gas/testsuite/gas/elf/dwarf2-8.d
index 037da87..b0c2f94 100644
--- a/gas/testsuite/gas/elf/dwarf2-8.d
+++ b/gas/testsuite/gas/elf/dwarf2-8.d
@@ -1,5 +1,3 @@
#as:
#name: DWARF2 8
#error_output: dwarf2-8.l
-# The tile targets require 8-byte instructions, but the test only simulates 4-byte instructions.
-#notarget: tile*-*
diff --git a/gas/testsuite/gas/elf/dwarf2-8.s b/gas/testsuite/gas/elf/dwarf2-8.s
index af9b306..02bdc3b 100644
--- a/gas/testsuite/gas/elf/dwarf2-8.s
+++ b/gas/testsuite/gas/elf/dwarf2-8.s
@@ -23,5 +23,5 @@ _start:
.file 1 "dwarf2-8.c"
.loc 1 1 view 0
.loc 1 2 view 0
- .int 0
+ .quad 0
.size _start, .-_start
diff --git a/gas/testsuite/gas/elf/dwarf2-9.d b/gas/testsuite/gas/elf/dwarf2-9.d
index 2493f80..f504861 100644
--- a/gas/testsuite/gas/elf/dwarf2-9.d
+++ b/gas/testsuite/gas/elf/dwarf2-9.d
@@ -1,5 +1,3 @@
#as:
#name: DWARF2 9
#error_output: dwarf2-9.l
-# The tile targets require 8-byte instructions, but the test only simulates 4-byte instructions.
-#notarget: tile*-*
diff --git a/gas/testsuite/gas/elf/dwarf2-9.s b/gas/testsuite/gas/elf/dwarf2-9.s
index db2f59c..62a337e 100644
--- a/gas/testsuite/gas/elf/dwarf2-9.s
+++ b/gas/testsuite/gas/elf/dwarf2-9.s
@@ -28,5 +28,5 @@ _start:
.text
.loc 1 2 view 0
- .int 0
+ .quad 0
.size _start, .-_start
diff --git a/gas/testsuite/gas/elf/elf.exp b/gas/testsuite/gas/elf/elf.exp
index 01d8b9d..41abf87 100644
--- a/gas/testsuite/gas/elf/elf.exp
+++ b/gas/testsuite/gas/elf/elf.exp
@@ -55,41 +55,50 @@ proc run_elf_list_test { name suffix opts readelf_opts readelf_pipe } {
# We're testing bits in obj-elf -- don't run on anything else.
if { [is_elf_format] } then {
set target_machine ""
- if {[istarget "mips*-*-*"]} then {
- set target_machine -mips
+ set dump_opts ""
+ if {[istarget "arc*-*-*"]} {
+ set target_machine -arc
+ }
+ if {[istarget "arm*-*-*"]} {
+ set target_machine -arm
+ }
+ if {[istarget "avr*-*-*"]} {
+ set dump_opts {{as -mno-link-relax}}
}
- if {[istarget m32r*-*-*]} then {
+ if {[istarget "m32r*-*-*"]} then {
set target_machine -m32r
}
+ if {[istarget "mips*-*-*"]} then {
+ set target_machine -mips
+ }
if {[istarget "msp430-*-*"]} then {
set target_machine -msp430
}
- if {[istarget "score-*-*"]} then {
- set target_machine -score
+ if {[istarget "pru-*-*"]} {
+ set dump_opts {{as -mno-link-relax}}
}
- if {[istarget "tic6x-*-*"]} then {
- set target_machine -tic6x
+ if {[istarget "riscv*-*-*"]} then {
+ set target_machine -riscv
+ set dump_opts {{as -mno-relax}}
}
- if {[istarget "xtensa*-*-*"]} then {
- set target_machine -xtensa
+ if {[istarget "rl78-*-*"]} then {
+ set target_machine -rl78
}
if {[istarget "rx-*-*"]} then {
set target_machine -rx
}
- if {[istarget "riscv*-*-*"]} then {
- set target_machine -riscv
+ if {[istarget "score-*-*"]} then {
+ set target_machine -score
+ }
+ if {[istarget "tic6x-*-*"]} then {
+ set target_machine -tic6x
}
if {[istarget "v850*-*-*"]} then {
set target_machine -v850
}
- if {[istarget "rl78-*-*"]} then {
- set target_machine -rl78
- }
- if {[istarget "arm*-*-*"]} {
- set target_machine -arm
- }
- if {[istarget "arc*-*-*"]} {
- set target_machine -arc
+ if {[istarget "xtensa*-*-*"]} then {
+ set target_machine -xtensa
+ set dump_opts {{as --no-link-relax}}
}
# The MN10300 and Xtensa ports disable the assembler's call frame
@@ -233,25 +242,25 @@ if { [is_elf_format] } then {
run_dump_test "section12b"
run_dump_test "section13"
run_dump_test "section14"
- run_dump_test "dwarf2-1"
- run_dump_test "dwarf2-2"
- run_dump_test "dwarf2-3"
- run_dump_test "dwarf2-4"
- run_dump_test "dwarf2-5"
- run_dump_test "dwarf2-6"
- run_dump_test "dwarf2-7"
- run_dump_test "dwarf2-8"
- run_dump_test "dwarf2-9"
- run_dump_test "dwarf2-10"
- run_dump_test "dwarf2-11"
- run_dump_test "dwarf2-12"
- run_dump_test "dwarf2-13"
- run_dump_test "dwarf2-14"
- run_dump_test "dwarf2-15"
- run_dump_test "dwarf2-16"
- run_dump_test "dwarf2-17"
- run_dump_test "dwarf2-18"
- run_dump_test "dwarf2-19"
+ run_dump_test "dwarf2-1" $dump_opts
+ run_dump_test "dwarf2-2" $dump_opts
+ run_dump_test "dwarf2-3" $dump_opts
+ run_dump_test "dwarf2-4" $dump_opts
+ run_dump_test "dwarf2-5" $dump_opts
+ run_dump_test "dwarf2-6" $dump_opts
+ run_dump_test "dwarf2-7" $dump_opts
+ run_dump_test "dwarf2-8" $dump_opts
+ run_dump_test "dwarf2-9" $dump_opts
+ run_dump_test "dwarf2-10" $dump_opts
+ run_dump_test "dwarf2-11" $dump_opts
+ run_dump_test "dwarf2-12" $dump_opts
+ run_dump_test "dwarf2-13" $dump_opts
+ run_dump_test "dwarf2-14" $dump_opts
+ run_dump_test "dwarf2-15" $dump_opts
+ run_dump_test "dwarf2-16" $dump_opts
+ run_dump_test "dwarf2-17" $dump_opts
+ run_dump_test "dwarf2-18" $dump_opts
+ run_dump_test "dwarf2-19" $dump_opts
run_dump_test "bss"
run_dump_test "bad-bss"
run_dump_test "bad-section-flag"
diff --git a/gas/testsuite/gas/elf/section2.e-miwmmxt b/gas/testsuite/gas/elf/section2.e-miwmmxt
deleted file mode 100644
index 4ebeaf2..0000000
--- a/gas/testsuite/gas/elf/section2.e-miwmmxt
+++ /dev/null
@@ -1,10 +0,0 @@
-
-Symbol table '.symtab' contains 6 entries:
- +Num: +Value +Size +Type +Bind +Vis +Ndx +Name
- +0: 0+0 +0 +NOTYPE +LOCAL +DEFAULT +UND
- +1: 0+0 +0 +SECTION +LOCAL +DEFAULT +1
- +2: 0+0 +0 +SECTION +LOCAL +DEFAULT +2
- +3: 0+0 +0 +SECTION +LOCAL +DEFAULT +3
- +4: 0+0 +0 +SECTION +LOCAL +DEFAULT +5
- +5: 0+0 +0 +SECTION +LOCAL +DEFAULT +4
-
diff --git a/gas/testsuite/gas/elf/dwarf2-10.s b/gas/testsuite/gas/elf/dwarf2-10.s
index 7b5a6f1..6f72cff 100644
--- a/gas/testsuite/gas/elf/dwarf2-10.s
+++ b/gas/testsuite/gas/elf/dwarf2-10.s
@@ -17,16 +17,16 @@
.file "dwarf2-10.c"
.text
- .balign 4
+ .balign 8
.globl _start
_start:
.file 1 "dwarf2-10.c"
.loc 1 1 view 0
- .balign 4 /* No skip needed here... */
+ .balign 8 /* No skip needed here... */
.loc 1 2 view 0 /* so this zero-view check fails. */
- .int 0
+ .quad 0
.loc 1 3 view 0
- .balign 8 /* Skip 4 more bytes after .int... */
+ .balign 16 /* Skip 8 more bytes after .quad... */
.loc 1 4 view 0 /* so this is a zero view indeed. */
- .int 0
+ .quad 0
.size _start, .-_start